#
# spec file for package jenkins-x-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name jx

Name:           jenkins-x-cli
Version:        3.11.81
Release:        1.1
Summary:        CLI for Jenkins X
License:        Apache-2.0
URL:            https://github.com/jenkins-x/jx
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh
Provides:       jx = %{version}

%description
Jenkins X provides automated CI+CD for Kubernetes with Preview Environments on
Pull Requests using Cloud Native pipelines from Tekton.

This package contains the CLI called jx.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
# hash will be shortened by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

GO_VERSION="$(go version | sed -e 's/^[^0-9.]*\([0-9.]*\).*/\1/')"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/jenkins-x/jx/pkg/cmd/version.Version=%{version} \
   -X github.com/jenkins-x/jx/pkg/cmd/version.Revision=${COMMIT_HASH:0:8} \
   -X github.com/jenkins-x/jx/pkg/cmd/version.Branch=v%{version} \
   -X github.com/jenkins-x/jx/pkg/cmd/version.GitTreeState=clean \
   -X github.com/jenkins-x/jx/pkg/cmd/version.GoVersion=${GO_VERSION} \
   -X github.com/jenkins-x/jx/pkg/cmd/version.BuildDate=${BUILD_DATE}" \
   -o bin/%{executable_name} cmd/main.go

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Tue Apr 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.81:
  * chore(deps): bump sigstore/cosign-installer from 3.8.1 to 3.8.2
* Tue Apr 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.80:
  * chore(deps): bump anchore/sbom-action from 0.18.0 to 0.19.0
* Tue Apr 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.79:
  * chore(deps): upgrade jenkins-x-plugins/jx-gitops to version
    0.26.0
* Fri Apr 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.78:
  * chore(deps): upgrade jenkins-x-plugins/jx-gitops to version
    0.25.3
* Fri Apr 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.77:
  * chore(deps): upgrade jenkins-x-plugins/jx-gitops to version
    0.25.2
* Mon Apr  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.76:
  * chore(deps): upgrade jenkins-x-plugins/jx-project to version
    0.2.74
* Sat Apr  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.75:
  * chore(deps): upgrade jenkins-x-plugins/jx-changelog to version
    0.10.13
* Sat Apr  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.74:
  * chore(deps): upgrade jenkins-x-plugins/jx-verify to version
    0.3.12
* Sat Apr  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.73:
  * chore(deps): upgrade jenkins-x-plugins/jx-pipeline to version
    0.7.20
* Sat Apr  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.72:
  * chore(deps): upgrade to version 0.0.79
* Sat Apr  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.71:
  * chore(deps): upgrade to version 0.25.1
* Mon Mar 31 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.11.70:
  * chore(deps): upgrade to version 0.25.0
* Fri Mar 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.69:
  * chore(deps): upgrade jenkins-x-plugins/jx-preview to version
    0.5.7
* Fri Mar 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.68:
  * chore(deps): upgrade to version 0.3.7
* Thu Mar 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.67:
  * chore(deps): upgrade jenkins-x-plugins/jx-preview to version
    0.5.6
* Tue Mar 18 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.66:
  * chore(deps): upgrade to version 0.7.19
* Fri Mar 14 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.65:
  * chore(deps): upgrade to version 0.4.13
* Fri Mar 14 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.64:
  * chore(deps): upgrade to version 0.4.8
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.63:
  * chore(deps): upgrade jenkins-x-plugins/jx-admin to version
    0.3.17
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.62:
  * chore(deps): upgrade jenkins-x-plugins/jx-admin to version
    0.3.15
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.61:
  * chore(deps): upgrade to version 0.24.9
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.60:
  * chore(deps): upgrade to version 0.24.8
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.59:
  * chore(deps): upgrade to version 0.24.7
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.58:
  * chore(deps): bump sigstore/cosign-installer from 3.7.0 to 3.8.1
* Thu Mar 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.57:
  * chore(deps): upgrade to version 0.0.78
* Thu Mar  6 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.56:
  * chore(deps): upgrade to version 0.24.6
* Fri Feb 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.55:
  * chore(deps): upgrade to version 0.3.11
* Fri Feb 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.54:
  * chore(deps): upgrade jenkins-x-plugins/jx-preview to version
    0.5.5
* Fri Feb 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.53:
  * chore(deps): upgrade to version 0.2.73
* Fri Feb 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.52:
  * chore(deps): upgrade to version 0.24.5
* Thu Feb 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.51:
  * chore(deps): upgrade to version 0.4.6
* Tue Feb 18 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.50:
  * chore(deps): upgrade to version 0.4.3
* Tue Feb 18 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.49:
  * chore(deps): upgrade to version 0.4.2
* Mon Feb 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.48:
  * chore(deps): upgrade to version 0.24.4
* Mon Feb 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.47:
  * chore(deps): upgrade to version 0.4.1
* Mon Feb 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.46:
  * chore(deps): upgrade to version 0.4.0
* Wed Feb 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.45:
  * chore(deps): upgrade to version 0.0.58
* Wed Feb 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.44:
  * chore(deps): upgrade to version 0.7.18
* Wed Feb 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.43:
  * fix: increase lint timeout
  * chore(deps): upgrade to version 0.24.3
* Wed Feb 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.42:
  * chore(deps): upgrade to version 0.4.12
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.41:
  * chore(deps): upgrade jenkins-x-plugins/jx-preview to version
    0.5.4
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.40:
  * chore(deps): upgrade jenkins-x-plugins/jx-preview to version
    0.5.3
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.39:
  * chore(deps): upgrade to version 0.24.2
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.38:
  * chore(deps): upgrade to version 0.0.55
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.37:
  * chore(deps): upgrade to version 0.3.10
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.36:
  * chore(deps): upgrade to version 0.23.14
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.35:
  * chore(deps): bump anchore/sbom-action from 0.17.9 to 0.18.0
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.34:
  * fix: clean away codeconv action files
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.33:
  * fix: set codeconv token
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.32:
  * chore(deps): upgrade to version 0.10.12
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.31:
  * chore(deps): upgrade jenkins-x-plugins/jx-admin to version
    0.3.14
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.30:
  * chore(deps): bump github.com/golang/glog
* Tue Jan 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.29:
  * chore(deps): bump codecov/codecov-action from 3 to 5
* Tue Jan 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.28:
  * chore(deps): bump jenkins-x-plugins/jx-release-version
* Thu Jan 23 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.27:
  * chore(deps): upgrade to version 0.3.5
* Thu Jan 23 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.26:
  * chore(deps): upgrade jenkins-x-plugins/jx-admin to version
    0.3.13
* Tue Jan 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.25:
  * chore(deps): upgrade to version 0.23.13
* Mon Jan 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.24:
  * chore(deps): bump anchore/sbom-action from 0.17.5 to 0.17.9
* Mon Jan 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.23:
  * chore(deps): bump jenkins-x-plugins/jx-release-version
* Mon Jan 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.22:
  * chore(deps): upgrade to version 0.7.17
* Mon Jan 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.21:
  * chore(deps): upgrade jenkins-x-plugins/jx-admin to version
    0.3.12
- Update to version 3.11.20:
  * chore(deps): bump golang.org/x/net from 0.30.0 to 0.33.0
- Update to version 3.11.19:
  * chore(deps): bump docker/build-push-action from 4 to 6
- Update to version 3.11.18:
  * chore(deps): bump github/codeql-action from 2 to 3
- Update to version 3.11.17:
  * chore(deps): bump sigstore/cosign-installer from 2.8.1 to 3.7.0
- Update to version 3.11.16:
  * chore(deps): bump docker/login-action from 2 to 3
- Update to version 3.11.15:
  * chore(deps): bump docker/setup-qemu-action from 2 to 3
- Update to version 3.11.14:
  * chore(deps): upgrade to version 0.2.70
- Update to version 3.11.13:
  * chore(deps): upgrade to version 0.7.16
- Update to version 3.11.12:
  * chore(deps): upgrade to version 0.23.12
- Update to version 3.11.11:
  * chore(deps): upgrade to version 0.4.11
- Update to version 3.11.10:
  * chore(deps): upgrade to version 0.10.11
* Thu Jan 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.9:
  * chore(deps): upgrade jenkins-x-plugins/jx-secret to version
    0.4.10
* Thu Jan 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.8:
  * fix: don't require cluster for cli upgrade
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.7:
  * chore(deps): upgrade jenkins-x-plugins/jx-pipeline to version
    0.7.13
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.6:
  * chore(deps): upgrade jenkins-x-plugins/jx-project to version
    0.2.67
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.5:
  * chore(deps): upgrade jenkins-x-plugins/jx-admin to version
    0.3.9
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.4:
  * fix: update contributing go version and pre commit status
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.3:
  * chore(deps): upgrade jenkins-x-plugins/jx-gitops to version
    0.23.9
* Mon Dec 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package jenkins-x-cli: CLI for Jenkins-X. Jenkins X provides
  automated CI+CD for Kubernetes with Preview Environments on Pull
  Requests using Cloud Native pipelines from Tekton
